#! /usr/bin/env python
"""Print background filename

Print the filename of the current or previous background image.

This file is a part of XSetBg.

"""

import sys
from xsetbg_db import xsetbg_db

if not xsetbg_db:
    sys.exit("Error: no database found")


def usage(code=0):
    sys.stderr.write("Usage: %s [index]\n" % sys.argv[0])
    sys.exit(code)


def get_args():
    from getopt import getopt, GetoptError

    try:
        options, arguments = getopt(sys.argv[1:], "he:",
                                    ["help", "output-encoding="])
    except GetoptError:
        usage(1)

    index = 0
    output_encoding = None

    for option, value in options:
        if option in ("-h", "--help"):
            usage()
        elif option in ("-e", "--output-encoding"):
            output_encoding = value
        else:
            usage(2)

    if arguments:
        if len(arguments) == 1:
            try:
                index = int(arguments[0])
            except ValueError:
                usage(3)
        else:
            usage(4)

    if output_encoding is None:
        from m_lib.defenc import default_encoding
        output_encoding = default_encoding
    return index, output_encoding

index, output_encoding = get_args()

filename = xsetbg_db.select('last_shown IS NOT NULL',
                            orderBy='-last_shown')[index].full_name

print filename.encode(output_encoding)
